/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/


/**
 * dump un message sur la console
 * 
 * @param {String} message    message  afficher
 */
function jsdump(message) {
    Components.classes['@mozilla.org/consoleservice;1']
              .getService(Components.interfaces.nsIConsoleService)
              .logStringMessage(message);
}

/**
 * fabrique un hritage entre parent et fille
 * 
 * @param {Object} parent    celui qui donne les proprits, gnralement un prototype
 * @param {Object} fille     celui qui reoit les proprits du parent, gnralement un prototype
 */
function heriter(parent, fille) {
    for (var element in parent)
        fille[element] = parent[element];
}

/**
 * Convertit un mois numrique en mois texte
 * 
 * @param {int} m    numro du mois
 * @return {String} nom du mois
 */
function getMois(m) {
    switch (m) {
        case 1:
            return "janvier"; break;
        case 2:
            return "fvrier"; break;
        case 3:
            return "mars"; break;
        case 4:
            return "avril"; break;
        case 5:
            return "mai"; break;
        case 6:
            return "juin"; break;
        case 7:
            return "juillet"; break;
        case 8:
            return "aot"; break;
        case 9:
            return "septembre"; break;
        case 10:
            return "octobre"; break;
        case 11:
            return "novembre"; break;
        case 12:
            return "dcembre"; break;
        default:
            return ""; break;
    }
}

/**
 * Aide des modules AEL
 * @param {String} page
 */
function afficherAideAEL(page) {
	try {
		var url = getDirServeur() +"aide/AEL/"+ page;
		window.openDialog(url,'','chrome,centerscreen');
	} catch (e) {
        recup_erreur(e);
    }
}

/**
 * Enregistrer une mthode auprs d'un observateur
 *
 * @param   {Function} classe              classe dont dpend la mthode observe
 * @param   {String}   methode_observee    nom de la mthode observe
 * @param   {Object}   observateur         observateur qui va enregistrer la mthode
 * @param   {String}   methode_rappel      mthode de l'observateur qui va traiter les donnes
 */
function enregistrerObservateurMethode(classe, methode_observee, observateur, methode_rappel) {
    var methode_objet = classe.prototype[methode_observee];
    // sauvegarde
    classe.prototype[methode_observee+"Sauvegarde"] = methode_objet;
    var callback = observateur[methode_rappel];
    classe.prototype[methode_observee] = function () {
        var retval = methode_objet.apply(this, arguments);
        callback.call(observateur, retval);
    }
}

/**
 * Supprime l'enrenregistrement d'une mthode en revenant sur la mthode d'origine
 *
 * @param   {Function} classe              classe dont dpend la mthode observe
 * @param   {String}   methode_observee    nom de la mthode observe
 */
function supprimerObservateurMethode(classe, methode_observee) {
    var sauvegarde = classe.prototype[methode_observee + "Sauvegarde"];
    if (sauvegarde != null)
        classe.prototype[methode_observee] = classe.prototype[sauvegarde];
}
