/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/

/**
 * Demande le chargement pralable de la lib util.js de OpenSI, pour jsLoader 
 */

jsLoader.loadSubScript("chrome://opensi/content/libs/verif.js");

/**
 * Vrifie un code NAF europen (4 chiffres + 1 lettre)
 * 
 * @param {String} code_naf    code  tester
 * @return {boolean} true si le code est correct, false sinon
 */
function estCodeNafEuropeen(code_naf) {
    try {
        return code_naf.length == 5 &&
               isDigitList(code_naf.substring(0,4)) && 
               isAlpha(code_naf.charAt(4));
    } 
    catch (e) {
        recup_erreur(e);
    }
}

/**
 * Vrifie un code client
 * 
 * @param {String} code    chane code client de la forme C<num departement><num ordre>
 *                         La longueur totale du code est de 7 caractres, le premier numro d'ordre
 *                         est donc 0000
 * @return {boolean} true si le code est valide, false sinon
 */
function estCodeClient(code) {
    try {
	    return code.length == 7 &&
               isCleAlpha(code) &&
               code.charAt(0) == 'C' &&
               isDigitList(code.substring(1, 6));  
    } catch (e) {
    	recup_erreur(e);
    }
}

/**
 * Vrifie un code prospect
 * 
 * @param {String} code    chane code prospect de la forme P<num departement><num ordre>
 *                         La longueur totale du code est de 8 caractres, le premier numro d'ordre
 *                         est donc 00000
 * @return {boolean} true si le code est valide, false sinon                         
 */
function estCodeProspect(code) {
    try {
	    return code.length == 8 &&
               isCleAlpha(code) &&
               code.charAt(0) == 'P' &&
               isDigitList(code.substring(1, 7));  
    } catch (e) {
    	recup_erreur(e);
    }
}

/**
 * Vrifie un code postal
 * 
 * @param {String} code    chane code postal
 * @return {boolean} true si le code est valide, false sinon                         
 */
function estCodePostal(code) {
    try {
	    return code.length == 5 &&
               isDigitList(code.substring(0, 4));  
    } catch (e) {
    	recup_erreur(e);
    }
}

/**
 * Vrifie une chaine ascii, sans accents.
 * Accepte le tiret (-), underscore (_), lettres, chiffres et espace simple
 * @param {String} chaine
 * @return {boolean} true si c'est une chaine ascii, false sinon
 */
function estAscii(chaine) {
    try {
      	n = chaine.length;
	    i = 0;
  	    ok = true;
	    while (i < n && ok) {
		    c = chaine.charAt(i);
  		    ok = ((c <= 'z' && c >= 'a') || 
                  (c <= 'Z' && c >= 'A') ||
                  c == '_' ||
                  c == '-' ||
                  c == ' ' ||
                  (c <= '9' && c >= '0'));
	  	    i += 1;
  	    }
	    return ok;
    } catch (e) {
        recup_erreur(e);
    }
}