/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/


/**
 * Génération d'une fiche prospect standard
 */

package com.ael.crm.actions.documents.modeles;

import java.awt.Color;
import java.util.Iterator;

import org.opensi.util.pdf.MultiPagesDocument;
import org.opensi.util.pdf.TableBuilder;

import com.lowagie.text.DocumentException;
import com.lowagie.text.Font;
import com.lowagie.text.Image;
import com.lowagie.text.Phrase;
import com.lowagie.text.pdf.PdfPCell;
import com.lowagie.text.pdf.PdfPTable;

import com.ael.crm.metier.Communication;
import com.ael.crm.metier.Resolution;

/**
 * Une fiche prospect pour édition pdf
 * @author jm
 *
 */
public class FicheProspectStd extends MultiPagesDocument {


	private static final Font fontGras = new Font(Font.HELVETICA, 11, Font.BOLD);
	private static final Font fontNormal = new Font(Font.HELVETICA, 10, Font.NORMAL);
	private static final Font fontTitre = new Font(Font.HELVETICA , 16, Font.BOLD, Color.WHITE);

	private DataProspect data;	   // les données dynamiques du prospect

	/**
	 * Construit une <code>FicheProspectStd</code
	 * 
	 * @param	tempdir			dossier temporaire du fichier pdf
	 * @param	data_			données de prospect
	 * 
	 * @author jm
	 */
	public FicheProspectStd(String tempdir, DataProspect data_) throws Exception {
	
		super(tempdir);
			
		this.data = data_;
	}

	
	/* implémentation des fonctions de MultiPagesDocument */
	
	public PdfPTable firstHeader() throws DocumentException {
		
		TableBuilder tb = new TableBuilder();
		
		tb.add(makeDonneesProspect());
		tb.add(makeSpace(35));
		tb.add(makeTitreCommunications());
		
		return tb.getTable();	
	}
	
	/**
	 * Construit le middleHeader : ce qui est mis en début de page pour une nouvelle page
	 * On ne met que la raison sociale du prospect
	 */
	public PdfPTable middleHeader(int lastLine) throws DocumentException {
		return firstHeader();
	}
	
	/**
	 * Construit le lastFooter : ce qui termine le document
	 */
	public PdfPTable lastFooter() throws DocumentException {
		
		TableBuilder tb = new TableBuilder();
		
		if (this.nbLines() > 0)
			tb.add(makeFinPage());
		
		return tb.getTable();
	}
	
	/**
	 * Construit le middleFooter : ce qui termine une page si il y en a d'autres ensuite
	 */
	public PdfPTable middleFooter(int nbLinesPage, int lastLine) throws DocumentException {
	
		TableBuilder tb = new TableBuilder();
		
		tb.add(makeFinPage());
		
		return tb.getTable();		
	}
	
	public PdfPTable bodyLine(int numLine) throws DocumentException {
	
		Communication com = data.communications.get(numLine);
		return makeLigneCommunication(com);
	}
	
	public PdfPTable emptyLine(float emptyHeight) throws DocumentException {
		
		PdfPTable pptSpace = new PdfPTable(1);
		PdfPCell cell = new PdfPCell(pptSpace.getDefaultCell());
		cell.setBorder(PdfPCell.NO_BORDER);
		cell.setPhrase(new Phrase(""));
		pptSpace.addCell(cell);
		return pptSpace;
	}
	
	public int nbLines() {
		return data.communications.size();
	}
	
	public int nbEx() {
		return 1;
	}
	
	public Image imageFond() {
		return null;
	}

	/* méthodes internes */

	private PdfPTable makeSpace(int space) {
	
		PdfPTable pptSpace = new PdfPTable(1);
		PdfPCell cell = new PdfPCell(pptSpace.getDefaultCell());
		cell.setBorder(PdfPCell.NO_BORDER);
		cell.setFixedHeight(space);
		cell.setPhrase(new Phrase(""));
	
		pptSpace.addCell(cell);
	
		return pptSpace;
	}
	
	/**
	 * Construire les données du prospect
	 */
	private PdfPTable makeDonneesProspect() throws DocumentException {
		
		PdfPTable pptGlobal = new PdfPTable(1);
		pptGlobal.setWidthPercentage(100);
		
		PdfPTable pptDonneesProspect = new PdfPTable(1);
		pptDonneesProspect.setWidthPercentage(100);
		
		PdfPCell cell = new PdfPCell(pptDonneesProspect.getDefaultCell());
		cell.setHorizontalAlignment(PdfPCell.ALIGN_LEFT);
		cell.setVerticalAlignment(PdfPCell.ALIGN_MIDDLE);
		cell.setBorder(PdfPCell.NO_BORDER);
		//cell.setPaddingBottom(5);
		
		cell.setPhrase(new Phrase("Raison Sociale : " + data.raisonSociale, fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("Contact : " + data.getNomComplet(), fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("Adresse :", fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("          " + data.adresse, fontNormal));
		pptDonneesProspect.addCell(cell);
		
		if (!data.compAdresse.equals("")) {
			cell.setPhrase(new Phrase("          " + data.compAdresse, fontNormal));
			pptDonneesProspect.addCell(cell);
		}
		
		cell.setPhrase(new Phrase("          " + data.codePostal + " " + data.ville, fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("T\u00E9l : " + data.tel, fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("Mobile : " + data.mobile, fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("Fax : " + data.fax, fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("Email : " + data.email, fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("Site web : " + data.web, fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("Commentaires : " + data.divers, fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("Valeur : " + data.valeur, fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("Trait\u00E9 : " + (data.etat == 1 ? "oui" : "non" ), fontNormal));
		pptDonneesProspect.addCell(cell);
		
		cell.setPhrase(new Phrase("Newsletter : " + (data.mailing == 1 ? "oui" : "non" ), fontNormal));
		pptDonneesProspect.addCell(cell);
		
		PdfPCell cellProspect = new PdfPCell(pptDonneesProspect);
		cellProspect.setBorder(PdfPCell.BOX);
		pptGlobal.addCell(cellProspect);
		return pptGlobal;		
	}

	private PdfPTable makeTitreCommunications() {
		
		PdfPTable pptTitre = new PdfPTable(1);
		pptTitre.setWidthPercentage(100);
		
		PdfPCell cell = new PdfPCell(pptTitre.getDefaultCell());		
		cell.setBorder(PdfPCell.NO_BORDER);
		cell.setBackgroundColor(new Color(175,175,175));
		cell.setVerticalAlignment(PdfPCell.ALIGN_MIDDLE);
		cell.setHorizontalAlignment(PdfPCell.ALIGN_CENTER);
		cell.setFixedHeight(30);
		cell.setPaddingBottom(5);
		cell.setPhrase(new Phrase("C    O    M    M    U    N    I    C    A    T    I    O    N    S", fontTitre));
		
		pptTitre.addCell(cell);
		
		return pptTitre;	
	}
	
	private PdfPTable makeLigneCommunication(Communication com) throws DocumentException {
		PdfPTable pptCom = new PdfPTable(1);
		pptCom.setWidthPercentage(100);
		PdfPCell cell = new PdfPCell(pptCom.getDefaultCell());
		cell.setBorder(PdfPCell.NO_BORDER);
		
		cell.setPhrase(new Phrase("Date : " + com.getDateCommunicationFormatee(), fontNormal));
		pptCom.addCell(cell);
		
		cell.setPhrase(new Phrase("Canal : " + com.getCanal(), fontNormal));
		pptCom.addCell(cell);
		
		cell.setPhrase(new Phrase("Créateur : " + com.getCreateur(), fontNormal));
		pptCom.addCell(cell);
		
		cell.setPhrase(new Phrase("Initiateur: " + com.getInitiateur(), fontNormal));
		pptCom.addCell(cell);
		
		cell.setPhrase(new Phrase("Commentaires : " + com.getCommentaire(), fontNormal));
		pptCom.addCell(cell);
		
		cell.setPhrase(new Phrase(""));
		pptCom.addCell(cell);
		
		PdfPCell cellResolutions = new PdfPCell(makeResolutionsCommunication(com));
		pptCom.addCell(cellResolutions);
		
		return pptCom;
	}
	
	private PdfPTable makeResolutionsCommunication(Communication com) {
		PdfPTable pptResolutions = new PdfPTable(1);
		pptResolutions.setWidthPercentage(100);
		PdfPCell cellResolutions = new PdfPCell(pptResolutions.getDefaultCell());
		cellResolutions.setPaddingLeft(50);
		cellResolutions.setBorder(PdfPCell.NO_BORDER);
		
		Iterator<Resolution> it = com.getResolutions().iterator();
		while (it.hasNext()) {
			Resolution r = it.next();
			cellResolutions.setHorizontalAlignment(PdfPCell.ALIGN_LEFT);
			cellResolutions.setPhrase(new Phrase("Responsable : " + r.getResponsable(), fontNormal));
			pptResolutions.addCell(cellResolutions);
			
			cellResolutions.setPhrase(new Phrase("Statut : " + r.getStatut(), fontNormal));
			pptResolutions.addCell(cellResolutions);
			
			cellResolutions.setPhrase(new Phrase("Priorit\u00E9 : " + r.getPriorite(), fontNormal));
			pptResolutions.addCell(cellResolutions);
			
			cellResolutions.setPhrase(new Phrase("Ev\u00E8nement : " + r.getEvenement(), fontNormal));
			pptResolutions.addCell(cellResolutions);
			
			String dateEv = r.getDateEvenementFormatee();
			if (!dateEv.equals("")) {
				cellResolutions.setPhrase(new Phrase("Date \u00e9v\u00E8nement : " + dateEv, fontNormal));
				pptResolutions.addCell(cellResolutions);
			}
			
			String desc = r.getDescription();
			if (!desc.equals("")) {
				cellResolutions.setPhrase(new Phrase("Description : " + desc, fontNormal));
				pptResolutions.addCell(cellResolutions);
			}
			
			cellResolutions.setHorizontalAlignment(PdfPCell.ALIGN_CENTER);
			cellResolutions.setPhrase(new Phrase("**********************************"));
			pptResolutions.addCell(cellResolutions);
		}
		return pptResolutions;
	}
	
	private PdfPTable makeFinPage() {
		
		PdfPTable pptFP = new PdfPTable(1);
		pptFP.setWidthPercentage(100);
		
		PdfPCell cell = new PdfPCell(pptFP.getDefaultCell());
		cell.setBorder(PdfPCell.NO_BORDER);
		cell.setPhrase(new Phrase(""));
		cell.setPaddingBottom(0);
		cell.setPaddingTop(0);
		cell.setFixedHeight(1);
				
		pptFP.addCell(cell);
	
		return pptFP;
	}
	
}
